@@ -5,6 +5,7 @@ from trac import perm
 import tempfile
 import logging
 import subprocess
+import pkg_resources
 import clue.app
 from clue.app import config
 from clue.app import utils
@@ -338,10 +339,8 @@ class ProjectManager(object):
         tracadminpath, tracenvpath, svnrepopath = self._get_paths(prjid)
         tracconffile = os.path.join(tracenvpath, 'conf', 'trac.ini')
         tracconfig = config.Config(tracconffile)
-        f = open(os.path.join(clue.app.__path__[0],
-                              'skel', 'trac.ini.template'))
-        data = f.read()
-        f.close()
+        templatename = os.path.join('skel', 'trac.ini.template')
+        data = pkg_resources.resource_string(__name__, templatename)
         pb = utils.PathBuilder(self._workingdir)
         dbpath = pb(os.path.join('etc', 'cluemapper', 'cluemapper.db'))
         ini = data % {'auth_file': self._cluemapperconfig['base']['auth_file'],
