@@ -1,8 +1,15 @@
-import webob
 
 
 class RedirectApp(object):
     '''Simple middleware for configurable redirects.
+
+      >>> app = RedirectApp(None, '/foo/')
+      >>> app.gen_url({'PATH_INFO': ''})
+      '/foo'
+      >>> app.gen_url({'PATH_INFO': '/bar'})
+      '/foo/bar'
+      >>> ignored = app({'PATH_INFO': ''}, lambda x, y: None)
+
     '''
 
     def __init__(self, main_redirect, relative_redirect=None):
@@ -19,22 +26,9 @@ class RedirectApp(object):
         return loc
 
     def __call__(self, environ, start_response):
-        request = webob.Request(environ)
-        response = webob.Response(content_type='text/plain')
-
-        newurl = self.main_redirect
-        if self.relative_redirect:
-            part1 = request.application_url
-            if part1.endswith('/'):
-                part1 = part1[:-1]
-            part2 = self.main_redirect
-            if part2.startswith('/'):
-                part2 = part2[1:]
-            newurl = part1 + '/' + part2
-        response.headers['Location'] = newurl
-        response.status = '301 Moved Permanently'
-
-        return response(environ, start_response)
+        loc = self.gen_url(environ)
+        start_response('301 Moved Permanently', [('Location', loc)])
+        return ''
 
 
 def make_app(global_config, main_redirect, relative_redirect=None):
